%define major     5
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define gittag    152d6819b360c2e7b379ee3f373d444ab3df0895
%define shorttag  152d681
%define gitdate   20240102

%define rel 17

Summary:        A library for audio labelling
Name:           aubio
Version:        0.4.9
Release:        %mkrel %{rel}.git%{gitdate}
License:        GPLv2+
Group:          Sound/Utilities
Url:            https://aubio.org/
Source0:        https://aubio.org/pub/%{name}-%{shorttag}.tar.gz
Patch1:         aubio-0.4.2-libdir.patch
Patch4:         python3.8.patch
Patch5:         aubio-numpy-2.0.patch
Patch6:         aubio-ffmpeg7.patch

BuildRequires:  doxygen
BuildRequires:  ffmpeg-devel
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  swig
BuildRequires:  pkgconfig(lash-1.0)
BuildRequires:  pd-devel
BuildRequires:  docbook-to-man
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  txt2man
BuildRequires:  waf

%description
A library for audio labelling. Its features include segmenting
a sound file before each of its attacks, performing pitch
detection, tapping the beat and producing midi streams from
live audio. The name aubio comes from 'audio' with a typo:
several transcription errors are likely to be found in the
results too.

%package -n %{libname}
Summary:        Main library for %{name}
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libname}
Main library for %{name}.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files and headers for %{name}.

%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%prep
%autosetup -p1 -n %{name}-%{shorttag}

# rm -rv waflib

%build
%waf \
    --enable-fftw3 \
    --libdir=%{_libdir}
%waf_build -vv

# python3
%pyproject_wheel

%install
%waf_install --destdir=%{buildroot}

# python3
%pyproject_install
%pyproject_save_files aubio

# we don't want these
find %{buildroot} -name '*.la' -delete
rm %{buildroot}%{_libdir}/libaubio.a

%files
%doc AUTHORS README.md
%{_bindir}/*
%{_mandir}/man1/aubio*.1*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_docdir}/libaubio-doc/api
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n python3-%{name} -f %{pyproject_files}
%license COPYING
%doc README.md ChangeLog AUTHORS


%changelog
* Sat Jul 19 2025 daviddavid <daviddavid> 0.4.9-17.git20240102.mga10
+ Revision: 2257241
- rebuild for new flac 1.5.0

* Wed Jul 02 2025 umeabot <umeabot> 0.4.9-16.git20240102.mga10
+ Revision: 2242829
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 0.4.9-15.git20240102.mga10
+ Revision: 2160338
- rebuild for python3.13

* Tue Dec 10 2024 daviddavid <daviddavid> 0.4.9-14.git20240102.mga10
+ Revision: 2123350
- rebuild for new rubberband 4.0.0

* Mon Dec 09 2024 daviddavid <daviddavid> 0.4.9-13.git20240102.mga10
+ Revision: 2123154
- add archlinux patch to fix build with ffmpeg 7.x and numpy 2
- rebuild for new ffmpeg 7.1

* Mon Jul 15 2024 papoteur <papoteur> 0.4.9-12.git20240102.mga10
+ Revision: 2081610
- new version from git at 2024-01-02

* Mon Jan 01 2024 daviddavid <daviddavid> 0.4.9-11.mga10
+ Revision: 2024953
- add fedora patch to fix build
- use system waf
- switch to pyproject
- add patch to fix build with removed 'imp' in python 3.12
- rebuild for py3.12

* Wed Nov 02 2022 ghibo <ghibo> 0.4.9-10.mga9
+ Revision: 1901518
- Add patches from upstream to support libavcodec 59
- Add missed ffmpeg-devel to BR
- Add missed ffmpeg-devel to BR

* Wed Nov 02 2022 ghibo <ghibo> 0.4.9-8.mga9
+ Revision: 1901489
- pass --enable-fftw3 to allow power other than 2 (required by performous).
- Add txt2man to BR to build man pages.
- Add jack to BR.
- Add man pages to BR.

* Fri Apr 01 2022 umeabot <umeabot> 0.4.9-7.mga9
+ Revision: 1839342
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 0.4.9-6.mga9
+ Revision: 1774999
- rebuild for python-3.10

* Sun Mar 21 2021 neoclust <neoclust> 0.4.9-5.mga9
+ Revision: 1706825
- Rebuild against python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 0.4.9-4.mga8
+ Revision: 1531048
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Mon Sep 09 2019 wally <wally> 0.4.9-3.mga8
+ Revision: 1438930
- rebuild for python3.8

* Mon Aug 05 2019 wally <wally> 0.4.9-2.mga8
+ Revision: 1427393
- switch bindings build to python3
- loosen lib pkg requires
- drop unneeded requires handled by autodep generators

* Tue Feb 19 2019 shlomif <shlomif> 0.4.9-1.mga7
+ Revision: 1368470
- New version 0.4.9

* Sat Dec 22 2018 shlomif <shlomif> 0.4.8-1.mga7
+ Revision: 1344476
- New version 0.4.8

* Sun Oct 14 2018 shlomif <shlomif> 0.4.7-1.mga7
+ Revision: 1320298
- New version 0.4.7

* Fri Sep 21 2018 umeabot <umeabot> 0.4.6-4.mga7
+ Revision: 1295096
- Mageia 7 Mass Rebuild

* Wed Jul 25 2018 shlomif <shlomif> 0.4.6-3.mga7
+ Revision: 1245246
- bump rel.
- Add a patch for mga#23211

* Sun Apr 01 2018 shlomif <shlomif> 0.4.6-2.mga7
+ Revision: 1214066
- Fix MGA#22849 - div by zero

* Tue Oct 24 2017 shlomif <shlomif> 0.4.6-1.mga7
+ Revision: 1173251
- New version 0.4.6

* Thu Jul 20 2017 shlomif <shlomif> 0.4.5-1.mga7
+ Revision: 1125523
- New version 0.4.5

* Sat Feb 13 2016 umeabot <umeabot> 0.4.2-2.mga6
+ Revision: 959544
- Mageia 6 Mass Rebuild

* Sun Nov 29 2015 shlomif <shlomif> 0.4.2-1.mga6
+ Revision: 907126
- Add missing BR
- Add missing BR
- Add missing BR
- New version 0.4.2

* Sat Jun 20 2015 shlomif <shlomif> 0.4.1-1.mga6
+ Revision: 835806
- synced patches
- New version 0.4.1

* Wed Oct 15 2014 umeabot <umeabot> 0.3.2-17.mga5
+ Revision: 747434
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.3.2-16.mga5
+ Revision: 725956
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.3.2-15.mga5
+ Revision: 678035
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.3.2-14.mga5
+ Revision: 628107
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.3.2-13.mga4
+ Revision: 546161
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 philippem <philippem> 0.3.2-12.mga4
+ Revision: 502242
- Fix byte-compilation error. Borrowed from Debian

* Fri Jan 11 2013 umeabot <umeabot> 0.3.2-11.mga3
+ Revision: 346570
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 29 2012 malo <malo> 0.3.2-10.mga3
+ Revision: 322752
- update RPM group

* Sat Dec 10 2011 eatdirt <eatdirt> 0.3.2-9.mga2
+ Revision: 180311
- Rebuilt for fftw-3.3
  Fix compilation failure due to missing symbols

* Tue Jun 14 2011 dmorgan <dmorgan> 0.3.2-8.mga2
+ Revision: 106324
- Do not package .la files

* Tue Mar 29 2011 ennael <ennael> 0.3.2-7.mga1
+ Revision: 78703
- clean spec file
- clean spec file
- imported package aubio


* Fri Nov 05 2010 Funda Wang <fwang@mandriva.org> 0.3.2-7mdv2011.0
+ Revision: 593668
- BR docbook-to-man
- fix python linakge

* Sat Feb 27 2010 Götz Waschk <waschk@mandriva.org> 0.3.2-7mdv2010.1
+ Revision: 512442
- rebuild for new libjack

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 0.3.2-6mdv2010.0
+ Revision: 436681
- rebuild

* Mon Dec 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.3.2-5mdv2009.1
+ Revision: 321018
- fix build on x86_64
- link against pd-devel
- use %%define _disable_ld_no_undefined 1
- Patch0: fix build with -Werror=format-security

* Mon Aug 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.3.2-2mdv2009.0
+ Revision: 270860
- fix provides for devel subpackage

* Mon Aug 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.3.2-1mdv2009.0
+ Revision: 270810
- add buildrequires on libsndfile-devel, libsamplerate-devel, libalsa-devel, swig, lash-devel and pd-devel
- fix file list
- add more provides for devel subpackage
- add source and spec files
- Created package structure for aubio.

